package com.ruoyi.hezhi.service;

import com.ruoyi.hezhi.domain.TbCase;
import com.ruoyi.hezhi.domain.vo.CaseVO;

import java.util.List;

/**
 * 案例Service接口
 *
 * @author ruoyi
 * @date 2024-09-14
 */
public interface ITbCaseService
{
    /**
     * 查询案例
     *
     * @param caseId 案例主键
     * @return 案例
     */
    public TbCase selectTbCaseByCaseId(Long caseId);

    /**
     * 查询案例列表
     *
     * @param tbCase 案例
     * @return 案例集合
     */
    public List<TbCase> selectTbCaseList(TbCase tbCase);

    /**
     * 新增案例
     *
     * @param tbCase 案例
     * @return 结果
     */
    public int insertTbCase(TbCase tbCase);

    /**
     * 修改案例
     *
     * @param tbCase 案例
     * @return 结果
     */
    public int updateTbCase(TbCase tbCase);

    /**
     * 批量删除案例
     *
     * @param caseIds 需要删除的案例主键集合
     * @return 结果
     */
    public int deleteTbCaseByCaseIds(Long[] caseIds);

    /**
     * 删除案例信息
     *
     * @param caseId 案例主键
     * @return 结果
     */
    public int deleteTbCaseByCaseId(Long caseId);

    /**
     * 案例list
     * @param caseTypeId 案例类型id 0全部
     * @return
     */
    public List<CaseVO> selectCaseListByType(Long caseTypeId);

    /**
     * 详情
     * @param id
     * @return
     */
    public CaseVO getDetail(Long id);
}
